lcvtoolbox.vision.encoding.image.encode\_image\_to\_bytes
=========================================================

.. currentmodule:: lcvtoolbox.vision.encoding.image

.. autofunction:: encode_image_to_bytes